@@ -46,11 +46,15 @@
 
 #define GLADE_XML_FILE "gnome-screensaver-preferences.glade"
 
+#define GNOME_LOCKDOWN_DIR  "/desktop/gnome/lockdown"
+#define KEY_LOCK_DISABLE    GNOME_LOCKDOWN_DIR "/disable_lock_screen"
+
 #define KEY_DIR             "/apps/gnome-screensaver"
+#define GNOME_SESSION_DIR   "/desktop/gnome/session"
 #define KEY_LOCK            KEY_DIR "/lock_enabled"
 #define KEY_IDLE_ACTIVATION_ENABLED         KEY_DIR "/idle_activation_enabled"
 #define KEY_MODE            KEY_DIR "/mode"
-#define KEY_ACTIVATE_DELAY  KEY_DIR "/idle_delay"
+#define KEY_ACTIVATE_DELAY  GNOME_SESSION_DIR "/idle_delay"
 #define KEY_LOCK_DELAY      KEY_DIR "/lock_delay"
 #define KEY_CYCLE_DELAY     KEY_DIR "/cycle_delay"
 #define KEY_THEMES          KEY_DIR "/themes"
@@ -169,7 +173,7 @@ static char *
 config_get_theme (gboolean *is_writable)
 {
         GConfClient *client;
-        char        *name = NULL;
+        char        *name;
         int          mode;
 
         client = gconf_client_get_default ();
@@ -189,6 +193,7 @@ config_get_theme (gboolean *is_writable)
 
         mode = config_get_mode (NULL);
 
+        name = NULL;
         if (mode == GS_MODE_BLANK_ONLY) {
                 name = g_strdup ("__blank-only");
         } else if (mode == GS_MODE_RANDOM) {
@@ -199,10 +204,12 @@ config_get_theme (gboolean *is_writable)
                                               KEY_THEMES,
                                               GCONF_VALUE_STRING,
                                               NULL);
-                if (list) {
+                if (list != NULL) {
                         name = g_strdup (list->data);
                 } else {
                         /* TODO: handle error */
+                        /* default to blank */
+                        name = g_strdup ("__blank-only");
                 }
 
                 g_slist_foreach (list, (GFunc)g_free, NULL);
@@ -322,6 +329,20 @@ config_get_lock (gboolean *is_writable)
         return lock;
 }
 
+static gboolean
+config_get_lock_disabled ()
+{
+        GConfClient *client;
+        gboolean     lock;
+
+        client = gconf_client_get_default ();
+
+        lock = gconf_client_get_bool (client, KEY_LOCK_DISABLE, NULL);
+
+        g_object_unref (client);
+        return lock;
+}
+
 static void
 config_set_lock (gboolean lock)
 {
@@ -390,7 +411,13 @@ preview_set_theme (GtkWidget  *widget,
 
                 themes = get_all_theme_ids (theme_manager);
                 if (themes != NULL) {
-                        job_set_theme (job, (const char *) themes->data);
+                        GSList *l;
+                        gint32  i;
+
+                        i = g_random_int_range (0, g_slist_length (themes));
+                        l = g_slist_nth (themes, i);
+
+                        job_set_theme (job, (const char *) l->data);
                         g_slist_foreach (themes, (GFunc) g_free, NULL);
                         g_slist_free (themes);
 
@@ -818,19 +845,19 @@ static void
 theme_installer_run (GtkWidget *prefs_dialog, GList *files)
 {
         GtkWidget *copy_dialog;
-        
+
         copy_dialog = copy_theme_dialog_new (files);
         g_list_foreach (files, (GFunc) (g_object_unref), NULL);
         g_list_free (files);
-        
+
         gtk_window_set_transient_for (GTK_WINDOW (copy_dialog),
                                         GTK_WINDOW (prefs_dialog));
         gtk_window_set_icon_name (GTK_WINDOW (copy_dialog),
-                                        "screensaver");
-        
+                                        "preferences-desktop-screensaver");
+
         g_signal_connect (copy_dialog, "complete",
                           G_CALLBACK (theme_copy_complete_cb), NULL);
-        
+
         copy_theme_dialog_begin (COPY_THEME_DIALOG (copy_dialog));
 }
 
@@ -866,11 +893,11 @@ uri_list_parse (const gchar *uri_list)
         gchar *retval;
         GFile *file;
         GList *result = NULL;
-        
+
         g_return_val_if_fail (uri_list != NULL, NULL);
-        
+
         p = uri_list;
-        
+
         /* We don't actually try to validate the URI according to RFC
          * 2396, or even check for allowed characters - we just ignore
          * comments and trim whitespace off the ends.  We also
@@ -880,27 +907,27 @@ uri_list_parse (const gchar *uri_list)
                 if (*p != '#') {
                         while (g_ascii_isspace (*p))
                                 p++;
-                        
+
                         q = p;
                         while ((*q != '\0')
                                && (*q != '\n')
                                && (*q != '\r'))
                                 q++;
-                        
+
                         if (q > p) {
                                 q--;
                                 while (q > p
                                        && g_ascii_isspace (*q))
                                         q--;
-                                
+
                                 retval = g_malloc (q - p + 2);
                                 strncpy (retval, p, q - p + 1);
                                 retval[q - p + 1] = '\0';
-                                
+
                                 file = g_file_new_for_uri (retval);
-                                
+
                                 g_free (retval);
-                                
+
                                 if (file != NULL)
                                         result = g_list_prepend (result, file);
                         }
@@ -909,7 +936,7 @@ uri_list_parse (const gchar *uri_list)
                 if (p != NULL)
                         p++;
         }
-        
+
         return g_list_reverse (result);
 }
 
@@ -928,11 +955,11 @@ drag_data_received_cb (GtkWidget        *widget,
 
         if (!(info == TARGET_URI_LIST || info == TARGET_NS_URL))
                 return;
-        
+
         files = uri_list_parse ((char *) selection_data->data);
         if (files != NULL) {
                 GtkWidget *prefs_dialog;
-                
+
                 prefs_dialog = glade_xml_get_widget (xml, "prefs_dialog");
                 theme_installer_run (prefs_dialog, files);
         }
@@ -1020,11 +1047,24 @@ invalid_type_warning (const char *type)
                    type);
 }
 
+static void
+ui_disable_lock (gboolean disable)
+{
+        GtkWidget *widget;
+
+        widget = glade_xml_get_widget (xml, "lock_checkbox");
+        gtk_widget_set_sensitive (widget, !disable);
+        if (disable) {
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), FALSE);
+        }
+}
+
 static void
 ui_set_lock (gboolean enabled)
 {
         GtkWidget *widget;
         gboolean   active;
+        gboolean   lock_disabled;
 
         widget = glade_xml_get_widget (xml, "lock_checkbox");
 
@@ -1032,6 +1072,8 @@ ui_set_lock (gboolean enabled)
         if (active != enabled) {
                 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), enabled);
         }
+        lock_disabled = config_get_lock_disabled ();
+        ui_disable_lock (lock_disabled);
 }
 
 static void
@@ -1040,6 +1082,7 @@ ui_set_enabled (gboolean enabled)
         GtkWidget *widget;
         gboolean   active;
         gboolean   is_writable;
+        gboolean   lock_disabled;
 
         widget = glade_xml_get_widget (xml, "enable_checkbox");
         active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
@@ -1052,6 +1095,8 @@ ui_set_enabled (gboolean enabled)
         if (is_writable) {
                 gtk_widget_set_sensitive (widget, enabled);
         }
+        lock_disabled = config_get_lock_disabled ();
+        ui_disable_lock(lock_disabled);
 }
 
 static void
@@ -1074,7 +1119,7 @@ key_changed_cb (GConfClient *client,
 
         key = gconf_entry_get_key (entry);
 
-        if (! g_str_has_prefix (key, KEY_DIR)) {
+        if (! g_str_has_prefix (key, KEY_DIR) && ! g_str_has_prefix (key, GNOME_LOCKDOWN_DIR)) {
                 return;
         }
 
@@ -1100,6 +1145,16 @@ key_changed_cb (GConfClient *client,
                 } else {
                         invalid_type_warning (key);
                 }
+        } else if (strcmp (key, KEY_LOCK_DISABLE) == 0) {
+                if (value->type == GCONF_VALUE_BOOL) {
+                        gboolean disabled;
+
+                        disabled = gconf_value_get_bool (value);
+
+                        ui_disable_lock (disabled);
+                } else {
+                        invalid_type_warning (key);
+                }
         } else if (strcmp (key, KEY_THEMES) == 0) {
                 if (value->type == GCONF_VALUE_LIST) {
                         GtkWidget *treeview;
@@ -1193,6 +1248,7 @@ fullscreen_preview_start_cb (GtkWidget *widget,
         gtk_widget_grab_focus (fullscreen_preview_window);
 
         fullscreen_preview_area = glade_xml_get_widget (xml, "fullscreen_preview_area");
+        preview_clear (fullscreen_preview_area);
         gs_job_set_widget (job, fullscreen_preview_area);
 }
 
@@ -1271,17 +1327,24 @@ get_best_visual (void)
         unsigned long v;
         char          c;
         GdkVisual    *visual;
+        gboolean      res;
 
         visual = NULL;
 
         command = g_build_filename (LIBEXECDIR, "gnome-screensaver-gl-helper", NULL);
 
         error = NULL;
-        g_spawn_command_line_sync (command,
-                                   &std_output,
-                                   NULL,
-                                   &exit_status,
-                                   &error);
+        res = g_spawn_command_line_sync (command,
+                                         &std_output,
+                                         NULL,
+                                         &exit_status,
+                                         &error);
+
+        if (! res) {
+                g_debug ("Could not run command '%s': %s", command, error->message);
+                g_error_free (error);
+                goto out;
+        }
 
         if (1 == sscanf (std_output, "0x%lx %c", &v, &c)) {
                 if (v != 0) {
@@ -1295,7 +1358,9 @@ get_best_visual (void)
                 }
         }
 
+ out:
         g_free (std_output);
+        g_free (command);
 
         return visual;
 }
@@ -1461,7 +1526,7 @@ init_capplet (void)
 
         setup_list_size_constraint (list_scroller, treeview);
         gtk_widget_set_size_request (preview, 480, 300);
-        gtk_window_set_icon_name (GTK_WINDOW (dialog), "screensaver");
+        gtk_window_set_icon_name (GTK_WINDOW (dialog), "preferences-desktop-screensaver");
         gtk_window_set_icon_name (GTK_WINDOW (fullscreen_preview_window), "screensaver");
 
         gtk_drag_dest_set (dialog, GTK_DEST_DEFAULT_ALL,
@@ -1503,6 +1568,13 @@ init_capplet (void)
                                  KEY_DIR,
                                  key_changed_cb,
                                  NULL, NULL, NULL);
+        gconf_client_add_dir (client, GNOME_LOCKDOWN_DIR,
+                              GCONF_CLIENT_PRELOAD_ONELEVEL,
+                              NULL);
+        gconf_client_notify_add (client,
+                                 GNOME_LOCKDOWN_DIR,
+                                 key_changed_cb,
+                                 NULL, NULL, NULL);
 
         g_object_unref (client);
 
