@@ -84,7 +84,7 @@ struct GSLockPlugPrivate
         GtkWidget   *auth_prompt_box;
         GtkWidget   *auth_capslock_label;
         GtkWidget   *auth_message_label;
-        GtkWidget   *away_message_label;
+        GtkWidget   *status_message_label;
 
         GtkWidget   *auth_unlock_button;
         GtkWidget   *auth_switch_button;
@@ -104,7 +104,7 @@ struct GSLockPlugPrivate
         gboolean     leave_note_enabled;
         gboolean     logout_enabled;
         char        *logout_command;
-        char        *away_message;
+        char        *status_message;
 
         guint        timeout;
 
@@ -134,7 +134,7 @@ enum {
         PROP_LOGOUT_ENABLED,
         PROP_LOGOUT_COMMAND,
         PROP_SWITCH_ENABLED,
-        PROP_AWAY_MESSAGE
+        PROP_STATUS_MESSAGE
 };
 
 static guint lock_plug_signals [LAST_SIGNAL];
@@ -157,7 +157,7 @@ gs_lock_plug_style_set (GtkWidget *widget,
                 return;
         }
 
-        gtk_container_set_border_width (GTK_CONTAINER (plug->priv->vbox), 24);
+        gtk_container_set_border_width (GTK_CONTAINER (plug->priv->vbox), 12);
         gtk_box_set_spacing (GTK_BOX (plug->priv->vbox), 12);
 
         gtk_container_set_border_width (GTK_CONTAINER (plug->priv->auth_action_area), 0);
@@ -311,7 +311,7 @@ is_capslock_on (void)
 
         dsp = GDK_DISPLAY ();
         if (XkbGetState (dsp, XkbUseCoreKbd, &states) != Success) {
-              return FALSE;
+                return FALSE;
         }
 
         return (states.locked_mods & LockMask) != 0;
@@ -623,8 +623,8 @@ image_set_from_pixbuf (GtkImage  *image,
 
         cairo_surface_destroy (surface);
 
-        gdk_pixmap_unref (bitmask);
-        gdk_pixmap_unref (pixmap);
+        g_object_unref (bitmask);
+        g_object_unref (pixmap);
 
         cairo_destroy (cr_mask);
         cairo_destroy (cr);
@@ -854,22 +854,22 @@ is_program_in_path (const char *program)
 }
 
 static void
-gs_lock_plug_set_away_message (GSLockPlug *plug,
-                               const char *away_message)
+gs_lock_plug_set_status_message (GSLockPlug *plug,
+                                 const char *status_message)
 {
         g_return_if_fail (GS_LOCK_PLUG (plug));
 
-        g_free (plug->priv->away_message);
-        plug->priv->away_message = g_strdup (away_message);
+        g_free (plug->priv->status_message);
+        plug->priv->status_message = g_strdup (status_message);
 
-        if (plug->priv->away_message_label) {
-                if (plug->priv->away_message) {
-                        gtk_label_set_text (GTK_LABEL (plug->priv->away_message_label),
-                                            plug->priv->away_message);
-                        gtk_widget_show (plug->priv->away_message_label);
+        if (plug->priv->status_message_label) {
+                if (plug->priv->status_message) {
+                        gtk_label_set_text (GTK_LABEL (plug->priv->status_message_label),
+                                            plug->priv->status_message);
+                        gtk_widget_show (plug->priv->status_message_label);
                 }
                 else {
-                        gtk_widget_hide (plug->priv->away_message_label);
+                        gtk_widget_hide (plug->priv->status_message_label);
                 }
         }
 }
@@ -894,8 +894,8 @@ gs_lock_plug_get_property (GObject    *object,
         case PROP_SWITCH_ENABLED:
                 g_value_set_boolean (value, self->priv->switch_enabled);
                 break;
-        case PROP_AWAY_MESSAGE:
-                g_value_set_string (value, self->priv->away_message);
+        case PROP_STATUS_MESSAGE:
+                g_value_set_string (value, self->priv->status_message);
                 break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -951,8 +951,8 @@ gs_lock_plug_set_property (GObject            *object,
         case PROP_LOGOUT_COMMAND:
                 gs_lock_plug_set_logout_command (self, g_value_get_string (value));
                 break;
-        case PROP_AWAY_MESSAGE:
-                gs_lock_plug_set_away_message (self, g_value_get_string (value));
+        case PROP_STATUS_MESSAGE:
+                gs_lock_plug_set_status_message (self, g_value_get_string (value));
                 break;
         case PROP_SWITCH_ENABLED:
                 gs_lock_plug_set_switch_enabled (self, g_value_get_boolean (value));
@@ -1025,17 +1025,17 @@ gs_lock_plug_class_init (GSLockPlugClass *klass)
         g_object_class_install_property (object_class,
                                          PROP_LOGOUT_COMMAND,
                                          g_param_spec_string ("logout-command",
-                                                               NULL,
-                                                               NULL,
-                                                               NULL,
-                                                               G_PARAM_READWRITE));
+                                                              NULL,
+                                                              NULL,
+                                                              NULL,
+                                                              G_PARAM_READWRITE));
         g_object_class_install_property (object_class,
-                                         PROP_AWAY_MESSAGE,
-                                         g_param_spec_string ("away-message",
-                                                               NULL,
-                                                               NULL,
-                                                               NULL,
-                                                               G_PARAM_READWRITE));
+                                         PROP_STATUS_MESSAGE,
+                                         g_param_spec_string ("status-message",
+                                                              NULL,
+                                                              NULL,
+                                                              NULL,
+                                                              G_PARAM_READWRITE));
         g_object_class_install_property (object_class,
                                          PROP_SWITCH_ENABLED,
                                          g_param_spec_boolean ("switch-enabled",
@@ -1703,7 +1703,7 @@ load_theme (GSLockPlug *plug)
 
         gtk_widget_show_all (lock_dialog);
 
-        plug->priv->away_message_label = glade_xml_get_widget (xml, "away-message-label");
+        plug->priv->status_message_label = glade_xml_get_widget (xml, "status-message-label");
 
         return TRUE;
 }
@@ -1743,17 +1743,9 @@ on_note_text_buffer_changed (GtkTextBuffer *buffer,
         }
 }
 
-#define INVISIBLE_CHAR_DEFAULT       '*'
-#define INVISIBLE_CHAR_BLACK_CIRCLE  0x25cf
-#define INVISIBLE_CHAR_WHITE_BULLET  0x25e6
-#define INVISIBLE_CHAR_BULLET        0x2022
-#define INVISIBLE_CHAR_NONE          0
-
 static void
 gs_lock_plug_init (GSLockPlug *plug)
 {
-        gunichar invisible_char;
-
         gs_profile_start (NULL);
 
         plug->priv = GS_LOCK_PLUG_GET_PRIVATE (plug);
@@ -1862,26 +1854,20 @@ gs_lock_plug_init (GSLockPlug *plug)
         gtk_entry_set_activates_default (GTK_ENTRY (plug->priv->auth_prompt_entry), TRUE);
         gtk_entry_set_visibility (GTK_ENTRY (plug->priv->auth_prompt_entry), FALSE);
 
-        /* Only change the invisible character if it '*' otherwise assume it is OK */
-        if ('*' == gtk_entry_get_invisible_char (GTK_ENTRY (plug->priv->auth_prompt_entry))) {
-                invisible_char = INVISIBLE_CHAR_BLACK_CIRCLE;
-                gtk_entry_set_invisible_char (GTK_ENTRY (plug->priv->auth_prompt_entry), invisible_char);
-        }
-
         g_signal_connect (plug->priv->auth_unlock_button, "clicked",
                           G_CALLBACK (unlock_button_clicked), plug);
 
         g_signal_connect (plug->priv->auth_cancel_button, "clicked",
                           G_CALLBACK (cancel_button_clicked), plug);
 
-        if (plug->priv->away_message_label) {
-              if (plug->priv->away_message) {
-                      gtk_label_set_text (GTK_LABEL (plug->priv->away_message_label),
-                                          plug->priv->away_message);
-              }
-              else {
-                      gtk_widget_hide (plug->priv->away_message_label);
-              }
+        if (plug->priv->status_message_label) {
+                if (plug->priv->status_message) {
+                        gtk_label_set_text (GTK_LABEL (plug->priv->status_message_label),
+                                            plug->priv->status_message);
+                }
+                else {
+                        gtk_widget_hide (plug->priv->status_message_label);
+                }
         }
 
         if (plug->priv->auth_switch_button != NULL) {
